@@ -1,6 +1,8 @@
 # fmt: off
 """Sphinx extension for making the spelling directive noop."""
 
+from __future__ import annotations
+
 from typing import Dict
 from typing import List
 from typing import Union
@@ -15,7 +17,7 @@ class SpellingNoOpDirective(SphinxDirective):
 
     has_content = True
 
-    def run(self) -> List[nodes.Node]:
+    def run(self) -> list[nodes.Node]:
         """Generate nothing in place of the directive.
 
         :returns: An empty list rather than a typical list of Docutils/Sphinx nodes
@@ -23,7 +25,7 @@ class SpellingNoOpDirective(SphinxDirective):
         return []
 
 
-def setup(app: Sphinx) -> Dict[str, Union[bool, str]]:
+def setup(app: Sphinx) -> dict[str, bool | str]:
     """Initialize the extension.
 
     :param app: An instance of sphinx
