@@ -104,10 +104,7 @@ pygments_style = "ansible"
 nitpicky = True
 root = "ansible_navigator"
 nitpick_ignore = [
-    ("py:class", "_Rule"),
-    ("py:class", "ansible_runner.runner.Runner"),
-    ("py:class", "argparse._SubParsersAction"),
-    ("py:class", "argparse.HelpFormatter"),
+    ("py:class", "ContentTypeSequence"),
     ("py:class", "Captures"),
     ("py:class", "CompiledRegsetRule"),
     ("py:class", "CompiledRule"),
@@ -116,20 +113,18 @@ nitpick_ignore = [
     ("py:class", "ContentView"),
     ("py:class", "CursesLine"),
     ("py:class", "CursesLines"),
-    ("py:class", "dataclasses.InitVar"),
     ("py:class", "Entry"),
     ("py:class", "FieldButton"),
     ("py:class", "FieldChecks"),
     ("py:class", "FieldInformation"),
     ("py:class", "FieldRadio"),
     ("py:class", "FieldWorking"),
-    ("py:class", "Form"),
     ("py:class", "Grammar"),
     ("py:class", "Grammars"),
-    ("py:class", "Internals"),
     ("py:class", "IO"),
+    ("py:class", "InitVar"),  # needed by py310 or lower
+    ("py:class", "Internals"),
     ("py:class", "Match"),
-    ("py:class", "multiprocessing.context.BaseContext.Queue"),
     ("py:class", "NavigatorPostProcessor"),
     ("py:class", "Pattern"),
     ("py:class", "PatternRule"),
@@ -139,12 +134,19 @@ nitpick_ignore = [
     ("py:class", "State"),
     ("py:class", "WhileRule"),
     ("py:class", "Window"),
+    ("py:class", "_Rule"),
+    ("py:class", "ansible_runner.runner.Runner"),
+    ("py:class", "argparse.HelpFormatter"),
+    ("py:class", "argparse._SubParsersAction"),
+    ("py:class", "dataclasses.InitVar"),
+    ("py:class", "multiprocessing.context.BaseContext.Queue"),
     ("py:class", "yaml.cyaml.CSafeDumper"),
+    ("py:class", "yaml.dumper.SafeDumper"),
     ("py:class", "yaml.nodes.ScalarNode"),
     ("py:class", f"{root}.configuration_subsystem.definitions.SettingsFileType"),
     ("py:class", f"{root}.configuration_subsystem.defs_presentable.PresentableSettingsEntries"),
-    ("py:class", f"{root}.configuration_subsystem.defs_presentable.TCli"),
-    ("py:class", f"{root}.configuration_subsystem.defs_presentable.TEnt"),
+    ("py:class", f"{root}.configuration_subsystem.defs_presentable.CliT"),
+    ("py:class", f"{root}.configuration_subsystem.defs_presentable.EntT"),
     ("py:class", f"{root}.tm_tokenize.fchainmap.TKey"),
     ("py:class", f"{root}.tm_tokenize.fchainmap.TValue"),
     ("py:class", f"{root}.ui_framework.curses_defs.CursesLine"),
@@ -261,11 +263,11 @@ root_doc = master_doc = "index"  # Sphinx 4+ / 3-
 
 # -- Options for extlinks extension ---------------------------------------
 extlinks = {
-    "issue": (f"{github_repo_url}/issues/%s", "#"),  # noqa: WPS323
-    "pr": (f"{github_repo_url}/pull/%s", "PR #"),  # noqa: WPS323
-    "commit": (f"{github_repo_url}/commit/%s", ""),  # noqa: WPS323
-    "gh": (f"{github_url}/%s", "GitHub: "),  # noqa: WPS323
-    "user": (f"{github_sponsors_url}/%s", "@"),  # noqa: WPS323
+    "issue": (f"{github_repo_url}/issues/%s", "#%s"),  # noqa: WPS323
+    "pr": (f"{github_repo_url}/pull/%s", "PR #%s"),  # noqa: WPS323
+    "commit": (f"{github_repo_url}/commit/%s", "%s"),  # noqa: WPS323
+    "gh": (f"{github_url}/%s", "GitHub: %s"),  # noqa: WPS323
+    "user": (f"{github_sponsors_url}/%s", "@%s"),  # noqa: WPS323
 }
 
 # -- Options for intersphinx extension ---------------------------------------
