@@ -1,36 +1,61 @@
-""" jump to one action
+"""A mechanism to start the main application loop for the text user interface.
+
+An instance of :class:`~ansible_navigator.action_runner.ActionRunner`
+is invoked once, after settings are parsed. A loop is entered and only
+exited when the user requests to quit.
+
+After initializing the user interface, an :class:`~ansible_navigator.ui_framework.ui.Interaction`
+is created from the fully initialized settings, and the requested
+action is run.
+
+From that point forward flow control of the application is handled
+by each action in the action stack, control returned here when
+``:quit`` is requested by the user.
 """
 import os
 
+from typing import TYPE_CHECKING
+
 from ansible_navigator.actions import kegexes
 from ansible_navigator.actions import run_action
-
-from .app import App
+from .action_base import ActionBase
+from .configuration_subsystem.definitions import ApplicationConfiguration
 from .steps import Steps
 from .ui_framework import Interaction
 from .ui_framework import UIConfig
 from .ui_framework import UserInterface
 
+
+if TYPE_CHECKING:
+    from _curses import _CursesWindow
+
+    Window = _CursesWindow
+else:
+    from typing import Any
+
+    Window = Any
+
 DEFAULT_REFRESH = 100
 DEFAULT_COLORS = "terminal_colors.json"
 THEME = "dark_vs.json"
 
 
-class ActionRunner(App):
+class ActionRunner(ActionBase):
+    """A single action runner."""
 
-    # pylint: disable=too-few-public-methods
-    # pylint: disable=too-many-instance-attributes
-    """the playbook ui"""
+    def __init__(self, args: ApplicationConfiguration) -> None:
+        """Initialize the ActionRunner class.
 
-    def __init__(self, args):
+        :param args: The current application configuration
+        """
         super().__init__(args, name="action_runner")
-        self._ui = None
+        self._ui: UserInterface
         self.steps: Steps = Steps()
 
     def initialize_ui(self, refresh: int) -> None:
-        """initialize the user interface
+        """Initialize the user interface.
 
-        :param refresh: The refresh for the ui
+        :param refresh: The refresh for the UI
         :type refresh: int
         """
         share_directory = self._args.internals.share_directory
@@ -46,25 +71,39 @@ class ActionRunner(App):
         )
 
         self._ui = UserInterface(
-            screen_miny=3,
+            screen_min_height=3,
             kegexes=kegexes,
             refresh=refresh,
             ui_config=config,
         )
 
-    def run(self, _screen) -> None:
+    def run(self, _screen: Window) -> None:
         # pylint: disable=protected-access
-        """Run with the interface and runner"""
+        """Run the app.
+
+        Initialize the UI.
+        Create an interaction based on the app name from the current settings.
+        Run the action, passing the interaction.
+
+        :param _screen: The screen instance from the curses wrapper call
+        """
         self.initialize_ui(DEFAULT_REFRESH)
         name, action = self._action_match(self._args.app)
         if name and action:
             interaction = Interaction(
-                name=name, action=action, menu=None, content=None, ui=self._ui._ui
+                name=name,
+                action=action,
+                menu=None,
+                content=None,
+                ui=self._ui._ui,
             )
             self._run_app(interaction)
 
     def _run_app(self, initial_interaction: Interaction) -> None:
-        """enter the endless loop"""
+        """Enter the endless app loop.
+
+        :param initial_interaction: The initial interaction for app start
+        """
         while True:
             if not self.steps:
                 self.steps.append(initial_interaction)
