@@ -1,4 +1,6 @@
 """Collections subcommand implementation."""
+from __future__ import annotations
+
 import curses
 import json
 import os
@@ -9,16 +11,12 @@ from copy import deepcopy
 from json.decoder import JSONDecodeError
 from pathlib import Path
 from typing import Any
-from typing import Dict
-from typing import List
-from typing import Optional
-from typing import Tuple
 from typing import cast
 
 from ..action_base import ActionBase
 from ..action_defs import RunStdoutReturn
 from ..app_public import AppPublic
-from ..configuration_subsystem import ApplicationConfiguration
+from ..configuration_subsystem.definitions import ApplicationConfiguration
 from ..content_defs import ContentFormat
 from ..runner import Command
 from ..steps import Step
@@ -36,7 +34,7 @@ from . import _actions as actions
 from . import run_action
 
 
-def color_menu(colno: int, colname: str, entry: Dict[str, Any]) -> Tuple[int, int]:
+def color_menu(colno: int, colname: str, entry: dict[str, Any]) -> tuple[int, int]:
     # pylint: disable=unused-argument
     """Provide a color for a collections menu entry in one column.
 
@@ -52,7 +50,7 @@ def color_menu(colno: int, colname: str, entry: Dict[str, Any]) -> Tuple[int, in
     return 2, 0
 
 
-def content_heading(obj: Any, screen_w: int) -> Optional[CursesLines]:
+def content_heading(obj: Any, screen_w: int) -> CursesLines | None:
     """Create a heading for collection content.
 
     :param obj: The content going to be shown
@@ -77,7 +75,7 @@ def content_heading(obj: Any, screen_w: int) -> Optional[CursesLines]:
     return CursesLines((CursesLine((line_1_part_1,)), CursesLine((line_2_part_1,))))
 
 
-def filter_content_keys(obj: Dict[Any, Any]) -> Dict[Any, Any]:
+def filter_content_keys(obj: dict[Any, Any]) -> dict[Any, Any]:
     """Filter out some keys when showing collection content.
 
     :param obj: The object from which keys should be removed
@@ -101,15 +99,15 @@ class Action(ActionBase):
         self._adjacent_collection_dir: str
         self._collection_cache: KeyValueStore
         self._collection_cache_path: str
-        self._collection_scanned_paths: List = []
-        self._collections: List = []
-        self._stats: Dict = {}
+        self._collection_scanned_paths: list = []
+        self._collections: list = []
+        self._stats: dict = {}
 
     def update(self) -> None:
         """Request calling app update, no collection update is required."""
         self._calling_app.update()
 
-    def run(self, interaction: Interaction, app: AppPublic) -> Optional[Interaction]:
+    def run(self, interaction: Interaction, app: AppPublic) -> Interaction | None:
         """Execute the ``collections`` request for mode interactive.
 
         :param interaction: The interaction from the user
@@ -365,7 +363,6 @@ class Action(ActionBase):
 
     def _run_runner(self) -> None:
         # pylint: disable=too-many-branches
-        # pylint: disable=too-many-locals
         # pylint: disable=too-many-statements
         """Use the runner subsystem to catalog collections."""
         if isinstance(self._args.set_environment_variable, dict):
@@ -554,13 +551,13 @@ class Action(ActionBase):
 
         return None
 
-    def _get_collection_plugins_details(self, selected_collection: Dict) -> Dict:
+    def _get_collection_plugins_details(self, selected_collection: dict) -> dict:
         """Get plugin details for the given collection.
 
         :param selected_collection: The selected collection
         :returns: The plugin details like full-name, type and short description.
         """
-        plugins_details: Dict = {}
+        plugins_details: dict = {}
 
         for plugin_checksum, plugin_info in selected_collection["plugin_checksums"].items():
 
@@ -592,13 +589,13 @@ class Action(ActionBase):
 
         return plugins_details
 
-    def _parse_collection_info_stdout(self) -> Dict:
+    def _parse_collection_info_stdout(self) -> dict:
         # pylint: disable=too-many-nested-blocks
         """Parse collection information from catalog collection cache.
 
         :returns: The collection information to be displayed on stdout
         """
-        collections_info: Dict = {
+        collections_info: dict = {
             "collections": [],
         }
         collection_exclude_keys = [
@@ -615,7 +612,7 @@ class Action(ActionBase):
         for collection in self._collections:
             plugins_details = self._get_collection_plugins_details(collection)
 
-            collection_stdout: Dict = {}
+            collection_stdout: dict = {}
             for info_name, info_value in collection.items():
                 info_name = remove_dbl_un(info_name)
                 if info_name in collection_exclude_keys:
