@@ -1,35 +1,40 @@
-""" :images """
+"""Images subcommand implementation."""
+from __future__ import annotations
+
 import curses
 import json
 import shlex
 
+from copy import deepcopy
 from functools import partial
-
 from typing import Any
-from typing import Dict
-from typing import List
-from typing import Tuple
-from typing import Union
 
-from . import run_action
-from . import _actions as actions
-
-from ..app import App
+from ..action_base import ActionBase
+from ..action_defs import RunStdoutReturn
 from ..app_public import AppPublic
-from ..configuration_subsystem import ApplicationConfiguration
+from ..configuration_subsystem import Constants
+from ..configuration_subsystem.definitions import ApplicationConfiguration
+from ..content_defs import ContentFormat
 from ..image_manager import inspect_all
-from ..runner.api import CommandRunner
+from ..runner import Command
 from ..steps import Step
-
+from ..ui_framework import CursesLine
 from ..ui_framework import CursesLinePart
 from ..ui_framework import CursesLines
 from ..ui_framework import Interaction
 from ..ui_framework import nonblocking_notification
 from ..ui_framework import warning_notification
+from ..utils.print import print_to_stdout
+from . import _actions as actions
+from . import run_action
 
 
-def filter_content_keys(obj: Dict[Any, Any]) -> Dict[Any, Any]:
-    """when showing content, filter out some keys"""
+def filter_content_keys(obj: dict[Any, Any]) -> dict[Any, Any]:
+    """Filter out some keys when showing image content.
+
+    :param obj: The object from which keys should be removed
+    :returns: The object with keys removed
+    """
     if isinstance(obj, list):
         working = [filter_content_keys(x) for x in obj]
         return working
@@ -43,29 +48,35 @@ def filter_content_keys(obj: Dict[Any, Any]) -> Dict[Any, Any]:
 
 
 @actions.register
-class Action(App):
-    """:images"""
-
-    # pylint: disable=too-few-public-methods
+class Action(ActionBase):
+    """Images subcommand implementation."""
 
     KEGEX = r"^im(?:ages)?(\s(?P<params>.*))?$"
 
     def __init__(self, args: ApplicationConfiguration):
+        """Initialize the ``:images`` action.
+
+        :param args: The current settings for the application
+        """
         super().__init__(args=args, logger_name=__name__, name="images")
-        self._image_list: List = []
+        self._image_list: list = []
         self._images = Step(
             name="images",
-            tipe="menu",
-            columns=["__name", "tag", "execution_environment", "created", "size"],
+            step_type="menu",
+            columns=["__image", "tag", "execution_environment", "created", "size"],
             value=[],
             select_func=self._build_image_menu,
         )
 
-    def color_menu(self, colno: int, colname: str, entry: Dict[str, Any]) -> Tuple[int, int]:
+    def color_menu(self, colno: int, colname: str, entry: dict[str, Any]) -> tuple[int, int]:
         # pylint: disable=unused-argument
+        """Provide a color for a images menu entry in one column.
 
-        """color the menu"""
-        # images list menu
+        :param colno: The column number
+        :param colname: The column name
+        :param entry: The menu entry
+        :returns: The color and decoration
+        """
         if "__full_name" in entry:
             if entry.get("execution_environment") is False:
                 return 8, 0
@@ -80,15 +91,21 @@ class Action(App):
                 return 12, 0
         return 2, 0
 
-    def generate_content_heading(self, obj: Dict, screen_w: int, name: str = "") -> CursesLines:
-        """generate the content heading"""
+    def generate_content_heading(self, obj: dict, screen_w: int, name: str = "") -> CursesLines:
+        """Create a heading for image content.
+
+        :param obj: The content going to be shown
+        :param screen_w: The current screen width
+        :param name: The name of the images menu
+        :returns: The heading
+        """
         if name == "image_menu":
             text = (
-                self.steps.previous.selected["image_name"]
-                + f" ({self.steps.previous.selected['description']})"
+                f"{self.steps.previous.selected['first_column']}"
+                f" ({self.steps.previous.selected['description']})"
             )
         elif name in ["python_package_list", "system_package_list"]:
-            text = f"{obj['name']} ({obj['version']})"
+            text = f"Name: {obj['name']} ({obj['version']})"
 
         color = 2
         if self._images.selected:
@@ -98,47 +115,111 @@ class Action(App):
                 color = 8
 
         empty_str = " " * (screen_w - len(text) + 1)
-        heading_str = (text + empty_str).upper()
-        heading = (
-            (
-                CursesLinePart(
-                    column=0,
-                    string=heading_str,
-                    color=color,
-                    decoration=curses.A_UNDERLINE | curses.A_BOLD,
-                ),
-            ),
+        heading_str = text + empty_str
+        line_part = CursesLinePart(
+            column=0,
+            string=heading_str,
+            color=color,
+            decoration=curses.A_UNDERLINE,
         )
-        return heading
+        return CursesLines((CursesLine((line_part,)),))
 
-    def run(self, interaction: Interaction, app: AppPublic) -> Union[Interaction, None]:
-        """Handle :images
+    def run_stdout(self) -> RunStdoutReturn:
+        """Handle settings in mode stdout.
+
+        :returns: RunStdoutReturn
+        """
+        self._logger.debug("images requested in stdout mode")
+
+        details_source = self._args.entry("images_details").value.source
+        if details_source is not Constants.DEFAULT_CFG:
+            return self.run_stdout_details()
+
+        self._collect_image_list()
+        if not self._images.value:
+            msg = "No images were found, or the configured container engine was not available."
+            return RunStdoutReturn(message=msg, return_code=1)
+        filtered = []
+        for image in self._images.value:
+            if image["execution_environment"] is False:
+                continue
+            image["name_tag"] = image["__name_tag"]
+            image["full_name"] = image["__full_name"]
+            filtered.append(filter_content_keys(image))
+        print_to_stdout(
+            content=filtered,
+            content_format=ContentFormat.YAML,
+            share_directory=self._args.internals.share_directory,
+            use_color=self._args.display_color,
+        )
+        return RunStdoutReturn(message="", return_code=0)
+
+    def run_stdout_details(self) -> RunStdoutReturn:
+        """Execute the ``images --details`` request for mode stdout.
+
+        :returns: A message and return code
+        """
+        image_name = self._args.execution_environment_image
+
+        output, error, return_code = self._run_runner(image_name=image_name)
+        if error or return_code:
+            return RunStdoutReturn(message=error, return_code=return_code)
+
+        details = self._parse(output)
+        if details is None:
+            message = "Image introspection failed, please check the logs and log an issue."
+            return RunStdoutReturn(message=message, return_code=1)
+
+        details.pop("errors")
+        sections = self._args.entry("images_details").value.current
+        for section_name, section in deepcopy(details).items():
+            if section_name not in sections and "everything" not in sections:
+                details.pop(section_name)
+            else:
+                for key in section:
+                    if key.startswith("__"):
+                        details[section_name].pop(key)
+
+        details["image_name"] = image_name
+        print_to_stdout(
+            content=details,
+            content_format=ContentFormat.YAML,
+            share_directory=self._args.internals.share_directory,
+            use_color=self._args.display_color,
+        )
+        return RunStdoutReturn(message="", return_code=0)
+
+    def run(self, interaction: Interaction, app: AppPublic) -> Interaction | None:
+        """Execute the ``images`` request for mode interactive.
 
         :param interaction: The interaction from the user
-        :type interaction: Interaction
         :param app: The app instance
-        :type app: App
+        :returns: The pending :class:`~ansible_navigator.ui_framework.ui.Interaction` or
+            :data:`None`
         """
         self._logger.debug("images requested")
         self._prepare_to_run(app, interaction)
 
-        self._update_args(
-            [self._name] + shlex.split(self._interaction.action.match.groupdict()["params"] or "")
+        args_updated = self._update_args(
+            [self._name] + shlex.split(self._interaction.action.match.groupdict()["params"] or ""),
         )
+        if not args_updated:
+            self._prepare_to_exit(interaction)
+            return None
 
         notification = nonblocking_notification(
-            messages=["Collecting available images, this may take a minute..."]
+            messages=["Collecting available images, this may take a minute..."],
         )
-        interaction.ui.show(notification)
+        interaction.ui.show_form(notification)
 
         self._collect_image_list()
         if not self._images.value:
             messages = [
-                "No images were found, or the configured container engine was not available."
+                "No images were found, or the configured container engine was not available.",
             ]
             messages.append("Please check the log (:log) for errors.")
             warning = warning_notification(messages=messages)
-            interaction.ui.show(warning)
+            interaction.ui.show_form(warning)
             self._logger.error(messages[0])
             return None
 
@@ -158,7 +239,7 @@ class Action(App):
         return None
 
     def _take_step(self) -> None:
-        """take one step"""
+        """Take a step based on the current step or step back."""
         result = None
         if isinstance(self.steps.current, Interaction):
             result = run_action(self.steps.current.name, self.app, self.steps.current)
@@ -176,7 +257,8 @@ class Action(App):
                 )
             elif self.steps.current.type == "content":
                 content_heading = partial(
-                    self.generate_content_heading, name=self.steps.previous.name
+                    self.generate_content_heading,
+                    name=self.steps.previous.name,
                 )
                 result = self._interaction.ui.show(
                     obj=self.steps.current.value,
@@ -191,6 +273,10 @@ class Action(App):
             self.steps.append(result)
 
     def _build_image_content(self) -> Step:
+        """Build the menu of image details.
+
+        :returns: The image details menu definition
+        """
         if self._images.selected is None:
             # an image should always be selected by now
             return self.steps.previous
@@ -198,7 +284,7 @@ class Action(App):
         if self.steps.current.index == 0:
             step = Step(
                 name="image_inspection",
-                tipe="content",
+                step_type="content",
                 value=self._images.selected["inspect"],
             )
             return step
@@ -206,7 +292,7 @@ class Action(App):
         if not self._images.selected["__introspected"]:
             message = "Collecting image details, this may take a minute..."
             notification = nonblocking_notification(messages=[message])
-            self._interaction.ui.show(notification)
+            self._interaction.ui.show_form(notification)
             introspection_success = self._introspect_image()
             if introspection_success is False:
                 return self.steps.previous
@@ -214,14 +300,14 @@ class Action(App):
         if self.steps.current.index == 1:
             step = Step(
                 name="general",
-                tipe="content",
+                step_type="content",
                 value=self._images.selected["general"],
             )
 
         elif self.steps.current.index == 2:
             step = Step(
                 name="ansible",
-                tipe="content",
+                step_type="content",
                 value=self._images.selected["ansible"],
             )
 
@@ -229,10 +315,11 @@ class Action(App):
             step = Step(
                 columns=["name", "version", "summary"],
                 name="python_package_list",
-                tipe="menu",
+                step_type="menu",
                 select_func=self._build_python_content,
                 value=sorted(
-                    self._images.selected["python"]["details"], key=lambda i: i["name"].lower()
+                    self._images.selected["python"]["details"],
+                    key=lambda i: i["name"].lower(),
                 ),
             )
 
@@ -240,67 +327,72 @@ class Action(App):
             step = Step(
                 columns=["name", "version", "summary"],
                 name="system_package_list",
-                tipe="menu",
+                step_type="menu",
                 select_func=self._build_system_content,
                 value=sorted(
-                    self._images.selected["system"]["details"], key=lambda i: i["name"].lower()
+                    self._images.selected["system"]["details"],
+                    key=lambda i: i["name"].lower(),
                 ),
             )
 
         elif self.steps.current.index == 5:
             step = Step(
                 name="everything",
-                tipe="content",
+                step_type="content",
                 value=self.steps.previous.selected,
             )
         return step
 
     def _build_image_menu(self) -> Step:
+        """Build the menu of images.
+
+        :returns: The images menu definition
+        """
         if self._images.selected is None:
             # an image should always be selected by now
             return self.steps.previous
 
-        image_name = f"{self._images.selected['__name_tag']}"
+        first_column = f"Image: {self._images.selected['__name_tag']}"
         menu = [
             {
-                image_name: "Image information",
+                first_column: "Image information",
                 "description": "Information collected from image inspection",
-            }
+            },
         ]
         if self.steps.current.selected["execution_environment"]:
             menu.append(
                 {
-                    image_name: "General information",
+                    first_column: "General information",
                     "description": "OS and python version information",
-                }
+                },
             )
             menu.append(
                 {
-                    image_name: "Ansible version and collections",
+                    first_column: "Ansible version and collections",
                     "description": "Information about ansible and ansible collections",
-                }
+                },
             )
             menu.append(
                 {
-                    image_name: "Python packages",
+                    first_column: "Python packages",
                     "description": "Information about python and python packages",
-                }
+                },
             )
             menu.append(
                 {
-                    image_name: "Operating system packages",
+                    first_column: "Operating system packages",
                     "description": "Information about operating system packages",
-                }
+                },
             )
-            menu.append({image_name: "Everything", "description": "All image information"})
+            menu.append({first_column: "Everything", "description": "All image information"})
         for menu_entry in menu:
-            menu_entry["image_name"] = image_name
+            menu_entry["first_column"] = first_column
 
-        columns = [image_name, "description"]
+        columns = [first_column, "description"]
         step = Step(
             columns=columns,
             name="image_menu",
-            tipe="menu",
+            step_type="menu",
             value=menu,
             select_func=self._build_image_content,
         )
@@ -308,22 +400,31 @@ class Action(App):
         return step
 
     def _build_python_content(self) -> Step:
+        """Build the content for an image's python packages.
+
+        :returns: The python package content
+        """
         return Step(
             name="python_content",
-            tipe="content",
+            step_type="content",
             value=self.steps.current.value,
             index=self.steps.current.index,
         )
 
     def _build_system_content(self) -> Step:
+        """Build the content for an image's system packages.
+
+        :returns: The system package content
+        """
         return Step(
             name="system_content",
-            tipe="content",
+            step_type="content",
             value=self.steps.current.value,
             index=self.steps.current.index,
         )
 
     def _collect_image_list(self):
+        """Build a list of images for the images menu."""
         images, error = inspect_all(container_engine=self._args.container_engine)
         if error or not images:
             self._logger.error(error)
@@ -332,6 +433,7 @@ class Action(App):
         for image in images:
             image["__introspected"] = False
             image["name"] = image["repository"].split("/")[-1]
+            image["__image"] = image["name"]
             image["__name_tag"] = f"{image['name']}:{image['tag']}"
             image["__full_name"] = f"{image['repository']}:{image['tag']}"
             image["__name"] = image["name"]
@@ -348,44 +450,29 @@ class Action(App):
         self._images.value = sorted(images, key=lambda i: i["name"])
 
     def _introspect_image(self) -> bool:
+        """Use the runner subsystem to introspect an image.
 
+        :returns: An indication of image introspection success
+        """
         if self._images.selected is None:
             # an image should always be selected by now
             return False
 
         self._images.selected["__introspected"] = True
-        share_directory = self._args.internals.share_directory
-        container_volume_mounts = [f"{share_directory}/utils:{share_directory}/utils"]
-        python_exec_path = "python3"
 
-        kwargs = {
-            "cmdline": [f"{share_directory}/utils/image_introspect.py"],
-            "container_engine": self._args.container_engine,
-            "container_volume_mounts": container_volume_mounts,
-            "execution_environment_image": self._images.selected["__full_name"],
-            "execution_environment": True,
-            "navigator_mode": "interactive",
-        }
-
-        if isinstance(self._args.container_options, list):
-            kwargs.update({"container_options": self._args.container_options})
-
-        self._logger.debug(
-            f"Invoke runner with executable_cmd: {python_exec_path}" + f" and kwargs: {kwargs}"
+        output, error, _return_code = self._run_runner(
+            image_name=self._images.selected["__full_name"],
         )
-        _runner = CommandRunner(executable_cmd=python_exec_path, **kwargs)
-        output, error, _ = _runner.run()
+
         if error:
             self._logger.error(
-                "Image introspection failed (runner), the return value was: %s", error
+                "Image introspection failed (runner), the return value was: %s",
+                error,
             )
             self.notify_failed()
             return False
         parsed = self._parse(output)
         if parsed is None:
-            self._logger.error(
-                "Image introspection failed (parsed), the return value was: %s", output[0:1000]
-            )
             self.notify_failed()
             return False
 
@@ -399,21 +486,25 @@ class Action(App):
                 "ansible": {
                     "collections": parsed["ansible_collections"],
                     "version": parsed["ansible_version"],
-                }
+                },
             }
             self._images.selected["python"] = parsed["python_packages"]
             self._images.selected["system"] = parsed["system_packages"]
         except KeyError:
             self._logger.exception(
-                "Image introspection failed (keys), the return value was: %s", output[0:1000]
+                "Image introspection failed (keys), the return value was: %s",
+                output[0:1000],
             )
             self.notify_failed()
             return False
         return True
 
-    def _parse(self, output) -> Union[Dict, None]:
-        """parse the introspection output"""
-        # pylint: disable=too-many-branches
+    def _parse(self, output) -> dict | None:
+        """Load and process the ``json`` output from the image introspection process.
+
+        :param output: The output from the image introspection process
+        :returns: The parsed output
+        """
         try:
             if not output.startswith("{"):
                 _warnings, json_str = output.split("{", 1)
@@ -426,14 +517,47 @@ class Action(App):
             self._logger.error("Unable to extract introspection from stdout")
             self._logger.debug("error json loading output: '%s'", str(exc))
             self._logger.debug(output)
+            self._logger.error(
+                "Image introspection failed (parsed), the return value was: %s",
+                output[0:1000],
+            )
             return None
 
         for error in parsed["errors"]:
             self._logger.error("%s %s", error["path"], error["error"])
         return parsed
 
+    def _run_runner(self, image_name: str) -> tuple[str, str, int]:
+        """Run runner to collect image details.
+
+        :param image_name: The full image name
+        :returns: Output, errors and the return code
+        """
+        share_directory = self._args.internals.share_directory
+        container_volume_mounts = [f"{share_directory}/utils:{share_directory}/utils"]
+        python_exec_path = "python3"
+
+        kwargs = {
+            "cmdline": [f"{share_directory}/utils/image_introspect.py"],
+            "container_engine": self._args.container_engine,
+            "container_volume_mounts": container_volume_mounts,
+            "execution_environment_image": image_name,
+            "execution_environment": True,
+            "navigator_mode": "interactive",
+        }
+
+        if isinstance(self._args.container_options, list):
+            kwargs.update({"container_options": self._args.container_options})
+
+        self._logger.debug(
+            f"Invoke runner with executable_cmd: {python_exec_path}" + f" and kwargs: {kwargs}",
+        )
+        _runner = Command(executable_cmd=python_exec_path, **kwargs)
+        output, error, return_code = _runner.run()
+        return output, error, return_code
+
     def notify_failed(self):
-        """notify introspection failed"""
+        """Notify image introspection failed."""
         msgs = ["humph. Something went really wrong while introspecting the image."]
         msgs.append("Details have been added to the log file")
         closing = ["[HINT] Please log an issue about this one, it shouldn't have happened"]
