@@ -1,3 +1,5 @@
+# cspell:ignore fqcn,FQCN
+
 """This action provides ansible-lint results through ansible-navigator.
 
 Internally, it works by using ansible-runner to execute ansible-lint (optionally
@@ -12,6 +14,8 @@ The full specification for ansible-lint's use of JSON (for the codeclimate
 formatter) can be found in src/ansiblelint/formatters/__init__.py in the
 ansible-lint codebase.
 """
+from __future__ import annotations
+
 import json
 import os
 import shlex
@@ -20,14 +24,11 @@ from collections.abc import Mapping
 from datetime import datetime
 from enum import IntEnum
 from typing import Any
-from typing import Dict
-from typing import Optional
-from typing import Tuple
 
 from ..action_base import ActionBase
 from ..action_defs import RunStdoutReturn
 from ..app_public import AppPublic
-from ..configuration_subsystem import ApplicationConfiguration
+from ..configuration_subsystem.definitions import ApplicationConfiguration
 from ..runner.command import Command
 from ..steps import Step
 from ..ui_framework import Color
@@ -89,7 +90,7 @@ def severity_to_color(severity: str) -> int:
     return Color.BLACK
 
 
-def color_menu(colno: int, colname: str, entry: Dict[str, Any]) -> Tuple[int, int]:
+def color_menu(colno: int, colname: str, entry: dict[str, Any]) -> tuple[int, int]:
     # pylint: disable=unused-argument
     """Color the menu.
 
@@ -101,7 +102,7 @@ def color_menu(colno: int, colname: str, entry: Dict[str, Any]) -> Tuple[int, in
     return (severity_to_color(entry["severity"]), Color.BLACK)
 
 
-def content_heading(obj: Dict, screen_w: int) -> CursesLines:
+def content_heading(obj: dict, screen_w: int) -> CursesLines:
     """Generate the content heading.
 
     :param obj: The content for which the heading will be generated
@@ -128,7 +129,7 @@ def content_heading(obj: Dict, screen_w: int) -> CursesLines:
     return CursesLines((CursesLine((line_1_part_1,)), CursesLine((line_2_part_1,))))
 
 
-def filter_content_keys(obj: Dict[Any, Any]) -> Dict[Any, Any]:
+def filter_content_keys(obj: dict[Any, Any]) -> dict[Any, Any]:
     """Filter out internal keys.
 
     :param obj: The content from which the content keys will be filtered
@@ -138,7 +139,7 @@ def filter_content_keys(obj: Dict[Any, Any]) -> Dict[Any, Any]:
     return {k: v for k, v in obj.items() if not k.startswith("__") and k not in ignored_keys}
 
 
-def massage_issue(issue: Dict) -> Dict:
+def massage_issue(issue: dict) -> dict:
     """Massage an issue by injecting some useful keys with strings for rendering.
 
     :param issue: The issue reported
@@ -146,7 +147,14 @@ def massage_issue(issue: Dict) -> Dict:
     """
     massaged = issue.copy()
     massaged["__severity"] = massaged["severity"].capitalize()
-    massaged["__message"] = issue["check_name"].split("] ", 1)[1].capitalize()
+    # Version 6.1 and before of ansible-lint used this syntax
+    # "check_name": "[fqcn-builtins] Use FQCN for builtin actions."
+    # Version 6.2 and later use this syntax
+    # check_name": "fqcn-builtins", "description": "Use FQCN for builtin actions."
+    if issue["check_name"].startswith("["):
+        massaged["__message"] = issue["check_name"].split("]")[1].strip()
+    else:
+        massaged["__message"] = issue["description"]
     massaged["__path"] = abs_user_path(issue["location"]["path"])
     if isinstance(issue["location"]["lines"]["begin"], Mapping):
         massaged["__line"] = issue["location"]["lines"]["begin"]["line"]
@@ -209,7 +217,7 @@ class Action(ActionBase):
         else:
             raise RuntimeError(msg)
 
-    def _run_runner(self) -> Tuple[str, str, int]:
+    def _run_runner(self) -> tuple[str, str, int]:
         """Spin up runner to run ansible-lint, either in an exec env or not.
 
         :returns: The output, errors and return code
@@ -272,7 +280,7 @@ class Action(ActionBase):
         return RunStdoutReturn(message="", return_code=return_code)
 
     @staticmethod
-    def _pull_out_json_or_fatal(stdout: str) -> Optional[str]:
+    def _pull_out_json_or_fatal(stdout: str) -> str | None:
         """
         Attempt to pull out JSON line from ansible-lint raw output.
 
@@ -291,7 +299,7 @@ class Action(ActionBase):
             return line
         return None
 
-    def run(self, interaction: Interaction, app: AppPublic) -> Optional[Interaction]:
+    def run(self, interaction: Interaction, app: AppPublic) -> Interaction | None:
         """Execute the ``lint`` request for mode interactive.
 
         :param interaction: The interaction from the user
@@ -358,7 +366,7 @@ class Action(ActionBase):
 
         :returns: The color
         """
-        max_severity = max([Severity[i["severity"].upper()].value for i in self._issues_menu.value])
+        max_severity = max(Severity[i["severity"].upper()].value for i in self._issues_menu.value)
         return severity_to_color(Severity(max_severity).name.lower())
 
     def _take_step(self) -> None:
