@@ -2,7 +2,7 @@
 import logging
 
 from ..app_public import AppPublic
-from ..configuration_subsystem import ApplicationConfiguration
+from ..configuration_subsystem.definitions import ApplicationConfiguration
 from ..ui_framework import Interaction
 from . import _actions as actions
 
@@ -21,7 +21,6 @@ class Action:
         self._args = args
         self._logger = logging.getLogger(__name__)
 
-    # pylint: disable=no-self-use
     def run(self, interaction: Interaction, app: AppPublic) -> None:
         """Execute the screen refresh request for mode interactive.
 
