@@ -1,4 +1,6 @@
 """Run subcommand implementation."""
+from __future__ import annotations
+
 import curses
 import json
 import logging
@@ -16,16 +18,13 @@ from queue import Queue
 from typing import Any
 from typing import Callable
 from typing import Dict
-from typing import List
-from typing import Optional
-from typing import Tuple
 
 from ..action_base import ActionBase
 from ..action_defs import RunStdoutReturn
 from ..app_public import AppPublic
-from ..configuration_subsystem import ApplicationConfiguration
 from ..configuration_subsystem import to_effective
 from ..configuration_subsystem import to_sources
+from ..configuration_subsystem.definitions import ApplicationConfiguration
 from ..content_defs import ContentView
 from ..content_defs import SerializationFormat
 from ..runner import CommandAsync
@@ -58,13 +57,20 @@ RESULT_TO_COLOR = [
     ("(?i)^in progress$", 8),
 ]
 
-get_color = lambda word: next(  # noqa: E731
-    (x[1] for x in RESULT_TO_COLOR if re.match(x[0], word)),
-    0,
-)
+
+def get_color(word):
+    """Retrieve color value matching the keyword.
+
+    :param word: Keyword to match color.
+    :returns: Color value
+    """
+    return next(  # noqa: E731
+        (x[1] for x in RESULT_TO_COLOR if re.match(x[0], word)),
+        0,
+    )
 
 
-def color_menu(_colno: int, colname: str, entry: Dict[str, Any]) -> Tuple[int, int]:
+def color_menu(_colno: int, colname: str, entry: dict[str, Any]) -> tuple[int, int]:
     # pylint: disable=too-many-branches
     """Find matching color for word.
 
@@ -110,7 +116,7 @@ def color_menu(_colno: int, colname: str, entry: Dict[str, Any]) -> Tuple[int, i
     return color, decoration
 
 
-def content_heading(obj: Any, screen_w: int) -> Optional[CursesLines]:
+def content_heading(obj: Any, screen_w: int) -> CursesLines | None:
     """Create a heading for some piece of content showing.
 
     :param obj: The content going to be shown
@@ -151,7 +157,7 @@ def content_heading(obj: Any, screen_w: int) -> Optional[CursesLines]:
     return None
 
 
-def filter_content_keys(obj: Dict[Any, Any]) -> Dict[Any, Any]:
+def filter_content_keys(obj: dict[Any, Any]) -> dict[Any, Any]:
     """Filter out some keys when showing collection content.
 
     :param obj: The object from which keys should be removed
@@ -204,7 +210,7 @@ class Action(ActionBase):
         super().__init__(args=args, logger_name=__name__, name="run")
 
         self._subaction_type: str
-        self._msg_from_plays: Tuple[Optional[str], Optional[int]] = (None, None)
+        self._msg_from_plays: tuple[str | None, int | None] = (None, None)
         self._queue: Queue = Queue()
         self.runner: CommandAsync
         self._runner_finished: bool
@@ -220,9 +226,9 @@ class Action(ActionBase):
             show_func=self._play_stats,
             select_func=self._task_list_for_play,
         )
-        self._task_list_columns: List[str] = TASK_LIST_COLUMNS
+        self._task_list_columns: list[str] = TASK_LIST_COLUMNS
         self._content_key_filter: Callable = filter_content_keys
-        self._task_cache: Dict[str, str] = {}
+        self._task_cache: dict[str, str] = {}
         """Task name storage from playbook_on_start using the task uuid as the key"""
 
     @property
@@ -277,7 +283,7 @@ class Action(ActionBase):
             )
         return RunStdoutReturn(message="", return_code=return_code)
 
-    def run(self, interaction: Interaction, app: AppPublic) -> Optional[Interaction]:
+    def run(self, interaction: Interaction, app: AppPublic) -> Interaction | None:
         """Run :run or :replay.
 
         :param interaction: The interaction from the user
@@ -450,7 +456,7 @@ class Action(ActionBase):
         self._logger.debug("Completed replay artifact request with mode %s", self.mode)
         return True
 
-    def _prompt_for_artifact(self, artifact_file: str) -> Dict[Any, Any]:
+    def _prompt_for_artifact(self, artifact_file: str) -> dict[Any, Any]:
         """Prompt for a valid artifact file.
 
         :param artifact_file: Artifact file
@@ -477,7 +483,7 @@ class Action(ActionBase):
         populated_form = form_to_dict(form, key_on_name=True)
         return populated_form
 
-    def _prompt_for_playbook(self) -> Dict[Any, Any]:
+    def _prompt_for_playbook(self) -> dict[Any, Any]:
         """Prepopulate a form to confirm the playbook details.
 
         :returns: Dict with playbook and inventory detail entries
@@ -566,7 +572,7 @@ class Action(ActionBase):
 
         :raises RuntimeError: If no ansible-playbook executable
         """
-        executable_cmd: Optional[str]
+        executable_cmd: str | None
 
         if self.mode == "stdout_w_artifact":
             mode = "interactive"
@@ -779,7 +785,7 @@ class Action(ActionBase):
             self._plays.value[idx]["__task_count"] = task_count
             completed = task_count - self._plays.value[idx]["__in progress"]
             if completed:
-                new = floor((completed / task_count * 100))
+                new = floor(completed / task_count * 100)
                 current = self._plays.value[idx].get("__percent_complete", 0)
                 self._plays.value[idx]["__percent_complete"] = max(new, current)
                 self._plays.value[idx]["__progress"] = str(max(new, current)) + "%"
@@ -847,7 +853,7 @@ class Action(ActionBase):
                 self._runner_finished = True
                 self._notify_no_tasks_redirect()
 
-    def _get_status(self) -> Tuple[str, int]:
+    def _get_status(self) -> tuple[str, int]:
         """Get the runner status and color for status message.
 
         :returns: status string, status color
@@ -875,7 +881,7 @@ class Action(ActionBase):
         status, status_color = self._get_status()
         self._interaction.ui.update_status(status, status_color)
 
-    def write_artifact(self, filename: Optional[str] = None) -> None:
+    def write_artifact(self, filename: str | None = None) -> None:
         """Write the artifact.
 
         :param filename: The file to write to
@@ -919,7 +925,7 @@ class Action(ActionBase):
                 )
                 self._logger.info("Saved artifact as %s", filename)
 
-            except (IOError, OSError) as exc:
+            except OSError as exc:
                 error = (
                     f"Saving the artifact file failed, resulted in the following error: f{str(exc)}"
                 )
