@@ -1,13 +1,16 @@
-""" :sample_notification, this is a blocking form
-"""
-from . import _actions as actions
-from ..app import App
+"""``:sample_notification`` command implementation."""
+
+from ..action_base import ActionBase
 from ..app_public import AppPublic
+from ..configuration_subsystem.definitions import ApplicationConfiguration
 from ..ui_framework import Interaction
 from ..ui_framework import dict_to_form
 from ..ui_framework import form_to_dict
-from .._yaml import yaml
+from ..utils.serialize import yaml
+from . import _actions as actions
 
+
+# cspell:disable
 FORM = """
 form:
   title:  BLOCKING NOTIFICATION
@@ -23,34 +26,35 @@ form:
       type: information
   type: notification
 """
+# cspell:enable
 
 
 @actions.register
-class Action(App):
-    """handle :sample_notification"""
-
-    # pylint: disable=too-few-public-methods
+class Action(ActionBase):
+    """``:sample_notification`` command implementation."""
 
     KEGEX = r"^sample_notification$"
 
-    def __init__(self, args):
+    def __init__(self, args: ApplicationConfiguration):
+        """Initialize the ``:sample_notification`` action.
+
+        :param args: The current settings for the application
+        """
         super().__init__(args=args, logger_name=__name__, name="sample_form")
 
-    # pylint: disable=unused-argument
     def run(self, interaction: Interaction, app: AppPublic) -> Interaction:
-        """Handle :doc
+        """Execute the ``:sample_notification`` request for mode interactive.
 
         :param interaction: The interaction from the user
-        :type interaction: Interaction
         :param app: The app instance
-        :type app: App
+        :returns: The pending :class:`~ansible_navigator.ui_framework.ui.Interaction`
         """
         self._logger.debug("sample notification requested")
         self._prepare_to_run(app, interaction)
 
         form_data = yaml.safe_load(FORM)
         form = dict_to_form(form_data["form"])
-        interaction.ui.show(form)
+        interaction.ui.show_form(form)
         as_dict = form_to_dict(form)
         self._logger.debug("form response: %s", as_dict)
 
