@@ -4,7 +4,7 @@ import time
 
 from ..action_base import ActionBase
 from ..app_public import AppPublic
-from ..configuration_subsystem import ApplicationConfiguration
+from ..configuration_subsystem.definitions import ApplicationConfiguration
 from ..ui_framework import Interaction
 from ..ui_framework import nonblocking_notification
 from . import _actions as actions
