@@ -1,12 +1,11 @@
 """The ansible-navigator configuration."""
+from __future__ import annotations
+
 import logging
 import os
 
 from dataclasses import dataclass
-from typing import List
-from typing import Optional
-from typing import Tuple
-from typing import Union
+from dataclasses import field
 
 from ..utils.definitions import ExitMessage
 from ..utils.definitions import LogMessage
@@ -26,8 +25,8 @@ from .utils import AnsibleConfiguration
 
 APP_NAME = "ansible_navigator"
 
-initialization_messages: List[LogMessage] = []
-initialization_exit_messages: List[ExitMessage] = []
+initialization_messages: list[LogMessage] = []
+initialization_exit_messages: list[ExitMessage] = []
 
 PLUGIN_TYPES = (
     "become",
@@ -93,14 +92,14 @@ def generate_share_directory():
 class Internals:
     """Place to hold an object that needs to be used from app initiation through whole app."""
 
-    ansible_configuration: AnsibleConfiguration = AnsibleConfiguration()
-    action_packages: Tuple[str] = ("ansible_navigator.actions",)
-    collection_doc_cache: Union[C, KeyValueStore] = C.NOT_SET
+    ansible_configuration: AnsibleConfiguration = field(default_factory=AnsibleConfiguration)
+    action_packages: tuple[str] = ("ansible_navigator.actions",)
+    collection_doc_cache: C | KeyValueStore = C.NOT_SET
     initializing: bool = False
     """This is an initial run (app starting for the first time)."""
     initialization_exit_messages = initialization_exit_messages
     initialization_messages = initialization_messages
-    settings_file_path: Optional[str] = None
+    settings_file_path: str | None = None
     settings_source: C = C.NOT_SET
     share_directory: str = generate_share_directory()
 
@@ -180,7 +179,7 @@ navigator_subcommands = [
             " in it. If not using an execution environment, ansible-lint must"
             " be installed on your system."
         ),
-        version_added="v1.0",
+        version_added="v2.0",
     ),
     SubCommand(
         name="replay",
@@ -364,7 +363,10 @@ NavigatorConfiguration = ApplicationConfiguration(
             cli_parameters=CliParameters(short="--eei"),
             settings_file_path_override="execution-environment.image",
             short_description="Specify the name of the execution environment image",
-            value=SettingsEntryValue(default="quay.io/ansible/creator-ee:v0.4.2"),
+            value=SettingsEntryValue(
+                default="quay.io/ansible/creator-ee:v0.9.1",
+                schema_default=C.NONE,
+            ),
             version_added="v1.0",
         ),
         SettingsEntry(
