@@ -1,4 +1,5 @@
 """Definitions of UI content objects."""
+from __future__ import annotations
 
 from dataclasses import asdict
 from dataclasses import dataclass
@@ -8,7 +9,6 @@ from typing import Any
 from typing import Dict
 from typing import Generic
 from typing import List
-from typing import Optional
 from typing import Sequence
 from typing import TypeVar
 from typing import Union
@@ -26,7 +26,7 @@ class ContentView(Enum):
 
 
 T = TypeVar("T")
-DictType: "TypeAlias" = Dict[str, T]
+DictType: TypeAlias = Dict[str, T]
 
 
 class SerializationFormat(Enum):
@@ -147,7 +147,7 @@ class CFormat:
     """The scope, used for tokenization"""
     file_extention: str
     """The file extension, with a ."""
-    serialization: Optional[SerializationFormat]
+    serialization: SerializationFormat | None
     """If needed the serialization format"""
 
 
