@@ -2,20 +2,18 @@
 
 These helpers are specific to ansible_navigator.
 """
+from __future__ import annotations
+
 import logging
 import os
 import sys
 
-from typing import List
 from typing import NoReturn
-from typing import Optional
-from typing import Tuple
-from typing import Union
 
 from ._version_doc_cache import __version_collection_doc_cache__ as VERSION_CDC
-from .configuration_subsystem import ApplicationConfiguration
 from .configuration_subsystem import Configurator
 from .configuration_subsystem import Constants as C
+from .configuration_subsystem.definitions import ApplicationConfiguration
 from .diagnostics import DiagnosticsCollector
 from .utils.definitions import ExitMessage
 from .utils.definitions import ExitMessages
@@ -27,7 +25,7 @@ from .utils.functions import find_settings_file
 from .utils.key_value_store import KeyValueStore
 
 
-def error_and_exit_early(exit_messages: List[ExitMessage]) -> NoReturn:
+def error_and_exit_early(exit_messages: list[ExitMessage]) -> NoReturn:
     """Exit the application early.
 
     :param exit_messages: List of all exit messages to be printed
@@ -38,7 +36,7 @@ def error_and_exit_early(exit_messages: List[ExitMessage]) -> NoReturn:
     sys.exit(1)
 
 
-def find_config() -> Tuple[List[LogMessage], List[ExitMessage], Optional[str], C]:
+def find_config() -> tuple[list[LogMessage], list[ExitMessage], str | None, C]:
     """Find a configuration file, logging each step.
 
     If the config can't be found/loaded, use default settings.
@@ -46,8 +44,8 @@ def find_config() -> Tuple[List[LogMessage], List[ExitMessage], Optional[str], C
 
     :returns: All log messages and config path
     """
-    messages: List[LogMessage] = []
-    exit_messages: List[ExitMessage] = []
+    messages: list[LogMessage] = []
+    exit_messages: list[ExitMessage] = []
     config_path = None
     settings_source = C.NONE
 
@@ -89,7 +87,7 @@ def find_config() -> Tuple[List[LogMessage], List[ExitMessage], Optional[str], C
 
 def get_and_check_collection_doc_cache(
     collection_doc_cache_path: str,
-) -> Tuple[List[LogMessage], List[ExitMessage], Optional[KeyValueStore]]:
+) -> tuple[list[LogMessage], list[ExitMessage], KeyValueStore | None]:
     """Ensure the collection doc cache has current application version as a safeguard.
 
     Always delete and rebuild if not.
@@ -97,8 +95,8 @@ def get_and_check_collection_doc_cache(
     :param collection_doc_cache_path: Path for collection documentation cache
     :returns: All messages and collection cache or None
     """
-    messages: List[LogMessage] = []
-    exit_messages: List[ExitMessage] = []
+    messages: list[LogMessage] = []
+    exit_messages: list[ExitMessage] = []
     message = f"Collection doc cache: 'path' is '{collection_doc_cache_path}'"
     messages.append(LogMessage(level=logging.DEBUG, message=message))
 
@@ -148,8 +146,8 @@ def get_and_check_collection_doc_cache(
 # pylint: disable=inconsistent-return-statements
 def _diagnose(
     args: ApplicationConfiguration,
-    exit_messages: List[ExitMessage],
-    messages: List[LogMessage],
+    exit_messages: list[ExitMessage],
+    messages: list[LogMessage],
     should_diagnose: bool,
 ):
     """Direct to the diagnostic information writer or return.
@@ -170,11 +168,11 @@ def _diagnose(
 
 
 def parse_and_update(
-    params: List,
+    params: list,
     args: ApplicationConfiguration,
-    apply_previous_cli_entries: Union[C, List[str]] = C.NONE,
+    apply_previous_cli_entries: C | list[str] = C.NONE,
     attach_cdc=False,
-) -> Tuple[List[LogMessage], List[ExitMessage]]:
+) -> tuple[list[LogMessage], list[ExitMessage]]:
     """Build a configuration.
 
     Return after the CDC is mounted, even if exit messages are generated, the CDC may still
@@ -186,8 +184,8 @@ def parse_and_update(
     :param attach_cdc: Should the collection doc cache be attached to the args.internals
     :returns: Log and exit messages
     """
-    messages: List[LogMessage] = []
-    exit_messages: List[ExitMessage] = []
+    messages: list[LogMessage] = []
+    exit_messages: list[ExitMessage] = []
     should_diagnose = "--diagnostics" in params
 
     (
