@@ -1,11 +1,10 @@
 """Get one line of text input."""
+from __future__ import annotations
+
 import curses
 
 from curses import ascii as curses_ascii
 from typing import TYPE_CHECKING
-from typing import List
-from typing import Tuple
-from typing import Union
 
 from .curses_defs import CursesLinePart
 from .curses_window import CursesWindow
@@ -49,7 +48,7 @@ class FormHandlerOptions(CursesWindow):
             clp_text = CursesLinePart(len(option_code) + 1, text, color, decoration)
             self._add_line(self.win, idx, ([clp_option_code, clp_text]))
 
-    def handle(self, idx, form_fields: List) -> Tuple[Union["FieldChecks", "FieldRadio"], int]:
+    def handle(self, idx, form_fields: list) -> tuple[FieldChecks | FieldRadio, int]:
         # pylint: disable=too-many-nested-blocks
         """Handle the check box field.
 
