@@ -1,21 +1,19 @@
-"""some UI specific utils
-"""
+"""Some UI specific utils."""
+from __future__ import annotations
+
 import functools
 import re
 
 from dataclasses import is_dataclass
 from math import floor
 from typing import Any
-from typing import Dict
-from typing import List
-from typing import Union
 
 from ..content_defs import ContentBase
 
 
 def convert_percentage(
-    content: Union[Dict[str, Any], ContentBase],
-    columns: List[str],
+    content: dict[str, Any] | ContentBase,
+    columns: list[str],
     progress_bar_width: int,
 ) -> None:
     """Convert an attribute or value to a progress bar formatted for the TUI in place.
@@ -51,7 +49,11 @@ def _string_to_progress(value: str, progress_bar_width: int) -> str:
 
 @functools.lru_cache(maxsize=None)
 def is_percent(string):
-    """is a string a percent?"""
+    """Determine if a string is a percentage.
+
+    :param string: The string to check
+    :returns: Boolean of comparison
+    """
     if string.endswith("%"):
         if re.match(r"^\d{1,3}%$", string):
             return True
@@ -59,13 +61,13 @@ def is_percent(string):
 
 
 def distribute(available, weights):
-    """distribute some available fairly
-    across a list of numbers
+    """Distribute some available fairly across a list of numbers.
 
     :param available: the total
     :type available: int
     :param weights: numbers
     :type weights: List[int]
+    :returns: List of distributed amounts available
     """
     total = sum(weights)
     if available < total:
