@@ -1,5 +1,4 @@
-"""Constants with default values used throughout the tests.
-"""
+"""Constants with default values used throughout the tests."""
 import os
 
 
@@ -10,6 +9,6 @@ FIXTURES_COLLECTION_DIR = os.path.abspath(
 
 # every attempt should be made for these images to share as many layers as possible
 # or really small
-DEFAULT_CONTAINER_IMAGE = "quay.io/ansible/creator-ee:v0.4.2"
+DEFAULT_CONTAINER_IMAGE = "quay.io/ansible/creator-ee:v0.9.1"
 SMALL_TEST_IMAGE = "quay.io/ansible/python-base:latest"
 PULLABLE_IMAGE = "registry.hub.docker.com/library/alpine:latest"
