@@ -1,4 +1,6 @@
 """the tmux session"""
+from __future__ import annotations
+
 import datetime
 import os
 import shlex
@@ -6,9 +8,6 @@ import time
 import warnings
 
 from timeit import default_timer as timer
-from typing import List
-from typing import Optional
-from typing import Union
 
 import libtmux
 
@@ -48,13 +47,13 @@ class TmuxSession:
         self.cli_prompt: str
         self._config_path = config_path
         self._cwd = cwd
-        self._fail_remaining: List = []
+        self._fail_remaining: list = []
         self._pane_height = pane_height
         self._pane_width = pane_width
         self._pull_policy = pull_policy
         self._session: libtmux.Session
         self._session_name = os.path.splitext(unique_test_id)[0]
-        self._setup_capture: List
+        self._setup_capture: list
         self._setup_commands = setup_commands or []
         self._shell_prompt_timeout = shell_prompt_timeout
         self._test_log_dir = generate_test_log_dir(unique_test_id)
@@ -197,7 +196,7 @@ class TmuxSession:
     def interaction(
         self,
         value,
-        search_within_response: Optional[Union[List, str]] = None,
+        search_within_response: list | str | None = None,
         ignore_within_response=None,
         timeout=300,
         send_clear: bool = True,
@@ -327,6 +326,11 @@ class TmuxSession:
         if mode == "shell" and send_clear:
             self._pane.send_keys("clear")
 
+        # Prior to libtmux v0.15, all empty lines were removed
+        # from the captured pane. For fixture readability, remove them here
+        # https://github.com/tmux-python/libtmux/pull/405/files
+        showing = [line for line in showing if line != ""]
+
         return showing
 
     def _get_cli_prompt(self):
