@@ -1,5 +1,4 @@
-"""Tests for images from CLI, interactive, without an EE.
-"""
+"""Tests for images from CLI, interactive, without an EE."""
 import pytest
 
 from ..._interactions import Command
