@@ -1,10 +1,9 @@
-"""Base class for run interactive/stdout tests.
-"""
+"""Base class for run interactive/stdout tests."""
+from __future__ import annotations
+
 import difflib
 import os
 
-from typing import Optional
-
 import pytest
 
 from ....defaults import FIXTURES_DIR
@@ -41,12 +40,16 @@ class BaseClass:
     """Base class for run interactive/stdout tests."""
 
     UPDATE_FIXTURES = False
-    TEST_FOR_MODE: Optional[str] = None
+    TEST_FOR_MODE: str | None = None
 
     @staticmethod
     @pytest.fixture(scope="module", name="tmux_session")
     def fixture_tmux_session(request):
-        """tmux fixture for this module"""
+        """Generate a tmux fixture for this module.
+
+        :param request: A fixture providing details about the test caller
+        :yields: A tmux session
+        """
         params = {
             "pane_height": "1000",
             "pane_width": "500",
@@ -61,8 +64,12 @@ class BaseClass:
 
     def test(self, request, tmux_session, step):
         # pylint: disable=too-many-branches
-        """Run the tests for run, mode and ``ee`` set in child class."""
+        """Run the tests for run, mode and ``ee`` set in child class.
 
+        :param request: A fixture providing details about the test caller
+        :param tmux_session: The tmux session to use
+        :param step: The commands to issue and content to look for
+        """
         if step.search_within_response is SearchFor.HELP:
             search_within_response = ":help help"
         elif step.search_within_response is SearchFor.PROMPT:
